@@ -4,22 +4,11 @@ use warnings;
 
 use Stenciller::Standard;
 use Stenciller::Stencil;
-# PODNAME:
-our $VERSION = '0.1003'; # VERSION
+# PODNAME: Stenciller
+our $VERSION = '0.1004'; # VERSION
 # ABSTRACT: Convert textfiles to different output
 
-package Stenciller;
-
-
-sub new {
-    shift;
-    Stenciller::Wrap->new(@_);
-}
-sub meta {
-    Stenciller::Wrap->meta;
-}
-
-class Stenciller::Wrap using Moose {
+class Stenciller using Moose {
 
     has filepath => (
         is => 'ro',
@@ -185,7 +174,7 @@ Stenciller - Convert textfiles to different output
 
 =head1 VERSION
 
-Version 0.1003, released 2015-01-15.
+Version 0.1004, released 2015-01-15.
 
 =head1 SYNOPSIS
 
