@@ -3,7 +3,7 @@ use warnings;
 
 use Moops;
 
-our $VERSION = '0.1003'; # VERSION
+our $VERSION = '0.1004'; # VERSION
 # PODNAME: Types::Stenciller
 # ABSTRACT: Types for Stenciller
 
@@ -15,7 +15,7 @@ declares Stencil, Renderer, Stenciller
 
 {
 
-    class_type Stenciller => { class => 'Stenciller::Wrap' };
+    class_type Stenciller => { class => 'Stenciller' };
     class_type Stencil    => { class => 'Stenciller::Stencil' };
 
 }
@@ -34,7 +34,7 @@ Types::Stenciller - Types for Stenciller
 
 =head1 VERSION
 
-Version 0.1003, released 2015-01-15.
+Version 0.1004, released 2015-01-15.
 
 =head1 SYNOPSIS
 
@@ -52,11 +52,11 @@ Defines a couple of types used in the C<Stenciller> namespace.
 
 =item *
 
-C<Stencil> is a L<Stenciller::Stencil>
+C<Stenciller> is a L<Stenciller>
 
 =item *
 
-C<Stenciller> is a L<Stenciller>
+C<Stencil> is a L<Stenciller::Stencil>
 
 =back
 
